@@ -8,7 +8,7 @@ Puppet::Type.type(:nova_aggregate).provide(
     Provider to manage nova aggregations
   EOT
 
-  @credentials = Puppet::Provider::Openstack::CredentialsV2_0.new
+  @credentials = Puppet::Provider::Openstack::CredentialsV3.new
 
   mk_resource_methods
 
@@ -21,7 +21,8 @@ Puppet::Type.type(:nova_aggregate).provide(
           :id => attrs[:id],
           :availability_zone => attrs[:availability_zone],
           :metadata => str2hash(attrs[:properties]),
-          :hosts => string2list(attrs[:hosts]).sort
+          :hosts => string2list(attrs[:hosts]).sort,
+          :filter_hosts => attrs[:filter_hosts]
       )
     end
   end
@@ -39,6 +40,11 @@ Puppet::Type.type(:nova_aggregate).provide(
     end
   end
 
+  def self.get_known_hosts
+    # get list of hosts known to be active from openstack
+    return request('compute service', 'list', ['--service', 'nova-compute']).map{|el| el[:host]}
+  end
+
   def exists?
     @property_hash[:ensure] == :present
   end
@@ -62,8 +68,11 @@ Puppet::Type.type(:nova_aggregate).provide(
       end
     end
     @property_hash = self.class.request('aggregate', 'create', properties)
-
     if not @resource[:hosts].nil? and not @resource[:hosts].empty?
+      # filter host list by known hosts if filter_hosts is set
+      if @resource[:filter_hosts] == :true
+        @resource[:hosts] = @resource[:hosts] & self.class.get_known_hosts()
+      end
       @resource[:hosts].each do |host|
         properties = [@property_hash[:name], host]
         self.class.request('aggregate', 'add host', properties)
@@ -77,7 +86,7 @@ Puppet::Type.type(:nova_aggregate).provide(
 
   def metadata=(value)
     # clear obsolete keys
-    # wip untill #1559866
+    # wip until #1559866
 #   if @property_hash[:metadata].keys.length > 0
 #     properties = [@resource[:name] ]
 #     (@property_hash[:metadata].keys - @resource[:metadata].keys).each do |key|
@@ -93,15 +102,20 @@ Puppet::Type.type(:nova_aggregate).provide(
   end
 
   def hosts=(value)
-    # remove hosts, which are not present in update
-    (@property_hash[:hosts] - @resource[:hosts]).each do |host|
-      properties = [@property_hash[:id], host]
-      self.class.request('aggregate', 'remove host', properties)
+    # filter host list by known hosts if filter_hosts is set
+    if @resource[:filter_hosts] == :true
+      value &= self.class.get_known_hosts()
     end
-    # add new hosts
-    (@resource[:hosts] - @property_hash[:hosts]).each do |host|
-      properties = [@property_hash[:id], host]
-      self.class.request('aggregate', 'add host', properties)
+    if not @property_hash[:hosts].nil?
+      # remove hosts that are not present in update
+      (@property_hash[:hosts] - value).each do |host|
+        self.class.request('aggregate', 'remove host', [@property_hash[:id], host])
+      end
+      # add hosts that are not already present
+      (value - @property_hash[:hosts]).each do |host|
+        self.class.request('aggregate', 'add host', [@property_hash[:id], host])
+      end
     end
   end
+
 end
