@@ -23,6 +23,11 @@
 #    Name for the new aggregate
 #    Required
 #
+#  [*filter_hosts*]
+#    A boolean-y value to toggle whether only hosts known to be active by
+#    openstack should be aggregated. i.e. "true" or "false"
+#    Optional, defaults to "false"
+#
 #  [*availability_zone*]
 #    The availability zone. ie "zone1"
 #    Optional
@@ -32,7 +37,7 @@
 #    Optional
 #
 #  [*hosts*]
-#    A comma seperated list with hosts or a single host. ie "host1,host2"
+#    A comma separated list with hosts or a single host. ie "host1,host2"
 #    Optional
 #
 
@@ -45,7 +50,7 @@ Puppet::Type.newtype(:nova_aggregate) do
   ensurable
 
   autorequire(:nova_config) do
-    ['auth_uri', 'project_name', 'username', 'password']
+    ['www_authenticate_uri', 'project_name', 'username', 'password']
   end
 
   newparam(:name, :namevar => true) do
@@ -60,6 +65,12 @@ Puppet::Type.newtype(:nova_aggregate) do
     end
   end
 
+  newparam(:filter_hosts) do
+    desc 'Toggle to filter given hosts so that only known nova-compute service hosts are added to the aggregate'
+    defaultto :false
+    newvalues(:true, :false)
+  end
+
   newproperty(:id) do
     desc 'The unique Id of the aggregate'
     validate do |v|
@@ -102,7 +113,7 @@ Puppet::Type.newtype(:nova_aggregate) do
   end
 
   newproperty(:hosts) do
-    desc 'Single host or comma seperated list of hosts'
+    desc 'Single host or comma separated list of hosts'
     #convert DSL/string form to internal form
     munge do |value|
       if value.is_a?(Array)
