@@ -8,15 +8,17 @@ describe 'nova::compute::libvirt' do
 
   shared_examples 'debian-nova-compute-libvirt' do
     let(:libvirt_options) do
-      if facts[:operatingsystem] == 'Ubuntu' and Puppet::Util::Package.versioncmp(facts[:operatingsystemmajrelease], '16') >= 0
-        'libvirtd_opts="-l"'
-      else
-        'libvirtd_opts="-d -l"'
-      end
+      'libvirtd_opts="-l"'
     end
 
     describe 'with default parameters' do
 
+      let :params do
+        {
+          :libvirt_cpu_model_extra_flags  => 'pcid,pdpe1gb',
+        }
+      end
+
       it { is_expected.to contain_class('nova::params')}
 
       it {
@@ -30,7 +32,7 @@ describe 'nova::compute::libvirt' do
 
       it {
         is_expected.to contain_package('libvirt').with(
-          :name   => 'libvirt-bin',
+          :name   => 'libvirtd',
           :ensure => 'present'
         )
         is_expected.to contain_package('libvirt').that_requires('Anchor[nova::install::begin]')
@@ -39,16 +41,19 @@ describe 'nova::compute::libvirt' do
 
       it {
         is_expected.to contain_service('libvirt').with(
-          :name   => 'libvirt-bin',
+          :name   => 'libvirtd',
           :enable => true,
           :ensure => 'running',
         )
       }
 
       it { is_expected.to contain_nova_config('DEFAULT/compute_driver').with_value('libvirt.LibvirtDriver')}
+      it { is_expected.to contain_nova_config('DEFAULT/preallocate_images').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/virt_type').with_value('kvm')}
       it { is_expected.to contain_nova_config('libvirt/cpu_mode').with_value('host-model')}
       it { is_expected.to contain_nova_config('libvirt/cpu_model').with_ensure('absent')}
+      it { is_expected.to contain_nova_config('libvirt/cpu_model_extra_flags').with_ensure('pcid,pdpe1gb')}
+      it { is_expected.to contain_nova_config('libvirt/snapshot_image_format').with_ensure('absent')}
       it { is_expected.to contain_nova_config('libvirt/disk_cachemodes').with_ensure('absent')}
       it { is_expected.to contain_nova_config('libvirt/inject_password').with_value(false)}
       it { is_expected.to contain_nova_config('libvirt/inject_key').with_value(false)}
@@ -57,6 +62,8 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('DEFAULT/remove_unused_base_images').with_ensure('absent')}
       it { is_expected.to contain_nova_config('DEFAULT/remove_unused_original_minimum_age_seconds').with_ensure('absent')}
       it { is_expected.to contain_nova_config('libvirt/remove_unused_resized_minimum_age_seconds').with_ensure('absent')}
+      it { is_expected.to contain_nova_config('libvirt/rx_queue_size').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/tx_queue_size').with_value('<SERVICE DEFAULT>')}
     end
 
     describe 'with params' do
@@ -66,8 +73,12 @@ describe 'nova::compute::libvirt' do
           :vncserver_listen                           => '0.0.0.0',
           :libvirt_cpu_mode                           => 'host-passthrough',
           :libvirt_cpu_model                          => 'kvm64',
+          :libvirt_cpu_model_extra_flags              => 'pcid',
+          :libvirt_snapshot_image_format              => 'raw',
           :libvirt_disk_cachemodes                    => ['file=directsync','block=none'],
           :libvirt_hw_disk_discard                    => 'unmap',
+          :libvirt_hw_machine_type                    => 'x86_64=machinetype1,armv7l=machinetype2',
+          :libvirt_enabled_perf_events                => ['cmt', 'mbml', 'mbmt'],
           :remove_unused_base_images                  => true,
           :remove_unused_resized_minimum_age_seconds  => 3600,
           :remove_unused_original_minimum_age_seconds => 3600,
@@ -75,6 +86,10 @@ describe 'nova::compute::libvirt' do
           :virtlock_service_name                      => 'virtlock',
           :virtlog_service_name                       => 'virtlog',
           :compute_driver                             => 'libvirt.FoobarDriver',
+          :preallocate_images                         => 'space',
+          :log_outputs                                => '1:file:/var/log/libvirt/libvirtd.log',
+          :rx_queue_size                              => 512,
+          :tx_queue_size                              => 1024,
         }
       end
 
@@ -83,15 +98,23 @@ describe 'nova::compute::libvirt' do
         :ensure => 'latest'
       ) }
       it { is_expected.to contain_nova_config('DEFAULT/compute_driver').with_value('libvirt.FoobarDriver')}
+      it { is_expected.to contain_nova_config('DEFAULT/preallocate_images').with_value('space')}
       it { is_expected.to contain_nova_config('libvirt/virt_type').with_value('qemu')}
       it { is_expected.to contain_nova_config('libvirt/cpu_mode').with_value('host-passthrough')}
       it { is_expected.to contain_nova_config('libvirt/cpu_model').with_ensure('absent')}
+      it { is_expected.to contain_nova_config('libvirt/cpu_model_extra_flags').with_ensure('pcid')}
+      it { is_expected.to contain_nova_config('libvirt/snapshot_image_format').with_ensure('absent')}
       it { is_expected.to contain_nova_config('libvirt/disk_cachemodes').with_value('file=directsync,block=none')}
       it { is_expected.to contain_nova_config('libvirt/hw_disk_discard').with_value('unmap')}
+      it { is_expected.to contain_nova_config('libvirt/hw_machine_type').with_value('x86_64=machinetype1,armv7l=machinetype2')}
+      it { is_expected.to contain_nova_config('libvirt/enabled_perf_events').with_value('cmt,mbml,mbmt')}
       it { is_expected.to contain_nova_config('vnc/vncserver_listen').with_value('0.0.0.0')}
       it { is_expected.to contain_nova_config('DEFAULT/remove_unused_base_images').with_value(true)}
       it { is_expected.to contain_nova_config('DEFAULT/remove_unused_original_minimum_age_seconds').with_value(3600)}
       it { is_expected.to contain_nova_config('libvirt/remove_unused_resized_minimum_age_seconds').with_value(3600)}
+      it { is_expected.to contain_libvirtd_config('log_outputs').with_value("\"#{params[:log_outputs]}\"")}
+      it { is_expected.to contain_nova_config('libvirt/rx_queue_size').with_value(512)}
+      it { is_expected.to contain_nova_config('libvirt/tx_queue_size').with_value(1024)}
       it {
         is_expected.to contain_service('libvirt').with(
           :name     => 'custom_service',
@@ -115,12 +138,30 @@ describe 'nova::compute::libvirt' do
 
     describe 'with custom cpu_mode' do
       let :params do
-        { :libvirt_cpu_mode  => 'custom',
-          :libvirt_cpu_model => 'kvm64' }
+        { :libvirt_cpu_mode              => 'custom',
+          :libvirt_cpu_model             => 'kvm64',
+          :libvirt_cpu_model_extra_flags => 'pcid' }
       end
 
       it { is_expected.to contain_nova_config('libvirt/cpu_mode').with_value('custom')}
       it { is_expected.to contain_nova_config('libvirt/cpu_model').with_value('kvm64')}
+      it { is_expected.to contain_nova_config('libvirt/cpu_model_extra_flags').with_value('pcid')}
+    end
+
+    describe 'with qcow2 as snapshot_image_format' do
+      let :params do
+        { :libvirt_snapshot_image_format => 'qcow2' }
+      end
+
+      it { is_expected.to contain_nova_config('libvirt/snapshot_image_format').with_value('qcow2')}
+    end
+
+    describe 'with qemu as virt_type' do
+      let :params do
+        { :libvirt_virt_type => 'qemu' }
+      end
+
+      it { is_expected.to contain_nova_config('libvirt/cpu_mode').with_value('none')}
     end
 
     describe 'with migration_support enabled' do
@@ -133,7 +174,7 @@ describe 'nova::compute::libvirt' do
 
         it { is_expected.to contain_class('nova::migration::libvirt')}
         it { is_expected.to contain_nova_config('vnc/vncserver_listen').with_value('0.0.0.0')}
-        it { is_expected.to contain_file_line('/etc/default/libvirt-bin libvirtd opts').with(:line => libvirt_options) }
+        it { is_expected.to contain_file_line('/etc/default/libvirtd libvirtd opts').with(:line => libvirt_options) }
         it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tls').with(:line => "listen_tls = 0") }
         it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tcp').with(:line => "listen_tcp = 1") }
         it { is_expected.not_to contain_file_line('/etc/libvirt/libvirtd.conf auth_tls')}
@@ -148,23 +189,13 @@ describe 'nova::compute::libvirt' do
 
         it { is_expected.to contain_class('nova::migration::libvirt')}
         it { is_expected.to contain_nova_config('vnc/vncserver_listen').with_value('::0')}
-        it { is_expected.to contain_file_line('/etc/default/libvirt-bin libvirtd opts').with(:line => libvirt_options) }
+        it { is_expected.to contain_file_line('/etc/default/libvirtd libvirtd opts').with(:line => libvirt_options) }
         it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tls').with(:line => "listen_tls = 0") }
         it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tcp').with(:line => "listen_tcp = 1") }
         it { is_expected.not_to contain_file_line('/etc/libvirt/libvirtd.conf auth_tls')}
         it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf auth_tcp').with(:line => "auth_tcp = \"none\"") }
       end
 
-      context 'with vncserver_listen not set to 0.0.0.0' do
-        let :params do
-          { :vncserver_listen  => '127.0.0.1',
-            :migration_support => true }
-        end
-
-        it { expect { is_expected.to contain_class('nova::compute::libvirt') }.to \
-          raise_error(Puppet::Error, /For migration support to work, you MUST set vncserver_listen to '0.0.0.0' or '::0'/) }
-      end
-
       context 'with custom libvirt service name on Debian platforms' do
         let :params do
           { :libvirt_service_name  => 'libvirtd',
@@ -260,7 +291,8 @@ describe 'nova::compute::libvirt' do
           :vncserver_listen                           => '0.0.0.0',
           :remove_unused_base_images                  => true,
           :remove_unused_resized_minimum_age_seconds  => 3600,
-          :remove_unused_original_minimum_age_seconds => 3600
+          :remove_unused_original_minimum_age_seconds => 3600,
+          :libvirt_enabled_perf_events                => ['cmt', 'mbml', 'mbmt']
         }
       end
 
@@ -269,6 +301,7 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('DEFAULT/remove_unused_base_images').with_value(true)}
       it { is_expected.to contain_nova_config('DEFAULT/remove_unused_original_minimum_age_seconds').with_value(3600)}
       it { is_expected.to contain_nova_config('libvirt/remove_unused_resized_minimum_age_seconds').with_value(3600)}
+      it { is_expected.to contain_nova_config('libvirt/enabled_perf_events').with_value('cmt,mbml,mbmt')}
       it { is_expected.to contain_package('libvirt').with(
         :name   => 'libvirt-daemon-kvm',
         :ensure => 'present'
@@ -307,15 +340,6 @@ describe 'nova::compute::libvirt' do
         it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf auth_tcp').with(:line => "auth_tcp = \"none\"") }
       end
 
-      context 'with vncserver_listen not set to 0.0.0.0' do
-        let :params do
-          { :vncserver_listen  => '127.0.0.1',
-            :migration_support => true }
-        end
-
-        it { expect { is_expected.to contain_class('nova::compute::libvirt') }.to \
-          raise_error(Puppet::Error, /For migration support to work, you MUST set vncserver_listen to '0.0.0.0'/) }
-      end
     end
 
     describe 'when manage_libvirt_services is set to false' do
