@@ -39,13 +39,25 @@ describe 'nova::conductor' do
       )}
     end
 
-    context 'with overriden workers parameter' do
+    context 'with overridden workers parameter' do
       let :params do
         {:workers => '5' }
       end
       it { is_expected.to contain_nova_config('conductor/workers').with_value('5') }
     end
 
+    context 'with default enable_new_services parameter' do
+      it { is_expected.to contain_nova_config('DEFAULT/enable_new_services').with_value('<SERVICE DEFAULT>') }
+    end
+
+    context 'with enable_new_services parameter set to false' do
+      let :params do
+        { :enable_new_services => false }
+      end
+
+      it { is_expected.to contain_nova_config('DEFAULT/enable_new_services').with_value(false) }
+    end
+
     context 'with default database parameters' do
       let :pre_condition do
         "include nova"
@@ -66,9 +78,11 @@ describe 'nova::conductor' do
         "
       end
 
-      it { is_expected.to contain_nova_config('database/connection').with_value('mysql://user:pass@db/db').with_secret(true) }
-      it { is_expected.to contain_nova_config('database/slave_connection').with_value('mysql://user:pass@slave/db').with_secret(true) }
-      it { is_expected.to contain_nova_config('database/idle_timeout').with_value('30') }
+      it { is_expected.to contain_oslo__db('nova_config').with(
+        :connection       => 'mysql://user:pass@db/db',
+        :slave_connection => 'mysql://user:pass@slave/db',
+        :idle_timeout     => '30',
+      )}
     end
 
   end
