@@ -37,17 +37,12 @@ describe 'nova' do
       end
 
       it 'configures auth_strategy' do
-        is_expected.to contain_nova_config('DEFAULT/auth_strategy').with_value('keystone')
+        is_expected.to contain_nova_config('api/auth_strategy').with_value('keystone')
         is_expected.to_not contain_nova_config('DEFAULT/use_deprecated_auth').with_value(false)
       end
 
       it 'configures rabbit' do
-        is_expected.to contain_nova_config('DEFAULT/rpc_backend').with_value('rabbit')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_password').with_value('<SERVICE DEFAULT>').with_secret(true)
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_userid').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_virtual_host').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_rate').with_value('<SERVICE DEFAULT>')
       end
@@ -58,11 +53,12 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/service_down_time').with_value('60')
         is_expected.to contain_nova_config('DEFAULT/rootwrap_config').with_value('/etc/nova/rootwrap.conf')
         is_expected.to contain_nova_config('DEFAULT/report_interval').with_value('10')
-        is_expected.to contain_nova_config('DEFAULT/use_ipv6').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('os_vif_linux_bridge/use_ipv6').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/control_exchange').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('cinder/os_region_name').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('cinder/catalog_info').with('value' => 'volumev2:cinderv2:publicURL')
+        is_expected.to contain_nova_config('cinder/catalog_info').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/cpu_allocation_ratio').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/ram_allocation_ratio').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/disk_allocation_ratio').with_value('<SERVICE DEFAULT>')
@@ -82,11 +78,7 @@ describe 'nova' do
           :image_service                           => 'nova.image.local.LocalImageService',
           :default_transport_url                   => 'rabbit://rabbit_user:password@localhost:5673',
           :rpc_response_timeout                    => '30',
-          :rpc_backend                             => 'rabbit',
-          :rabbit_host                             => 'rabbit',
-          :rabbit_userid                           => 'rabbit_user',
-          :rabbit_port                             => '5673',
-          :rabbit_password                         => 'password',
+          :control_exchange                        => 'nova',
           :rabbit_heartbeat_timeout_threshold      => '60',
           :rabbit_heartbeat_rate                   => '10',
           :lock_path                               => '/var/locky/path',
@@ -94,12 +86,12 @@ describe 'nova' do
           :service_down_time                       => '120',
           :auth_strategy                           => 'foo',
           :ensure_package                          => '2012.1.1-15.el6',
-          :memcached_servers                       => ['memcached01:11211', 'memcached02:11211'],
           :host                                    => 'test-001.example.org',
           :notification_transport_url              => 'rabbit://rabbit_user:password@localhost:5673',
           :notification_driver                     => 'ceilometer.compute.nova_notifier',
           :notification_topics                     => 'openstack',
-          :notify_api_faults                       => true,
+          :notification_format                     => 'unversioned',
+          :notify_on_api_faults                    => true,
           :report_interval                         => '60',
           :os_region_name                          => 'MyRegion',
           :use_ipv6                                => true,
@@ -115,6 +107,7 @@ describe 'nova' do
           :purge_config                            => false,
           :block_device_allocate_retries           => '60',
           :block_device_allocate_retries_interval  => '3',
+          :my_ip                                   => '192.0.2.1',
         }
       end
 
@@ -135,18 +128,14 @@ describe 'nova' do
       end
 
       it 'configures auth_strategy' do
-        is_expected.to contain_nova_config('DEFAULT/auth_strategy').with_value('foo')
+        is_expected.to contain_nova_config('api/auth_strategy').with_value('foo')
         is_expected.to_not contain_nova_config('DEFAULT/use_deprecated_auth').with_value(true)
       end
 
       it 'configures rabbit' do
-        is_expected.to contain_nova_config('DEFAULT/rpc_backend').with_value('rabbit')
         is_expected.to contain_nova_config('DEFAULT/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_host').with_value('rabbit')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_password').with_value('password').with_secret(true)
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_port').with_value('5673')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_userid').with_value('rabbit_user')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_virtual_host').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/rpc_response_timeout').with_value('30')
+        is_expected.to contain_nova_config('DEFAULT/control_exchange').with_value('nova')
         is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('60')
         is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_rate').with_value('10')
       end
@@ -155,6 +144,10 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/host').with_value('test-001.example.org')
       end
 
+      it 'configures my_ip' do
+        is_expected.to contain_nova_config('DEFAULT/my_ip').with_value('192.0.2.1')
+      end
+
       it 'configures upgrade_levels' do
         is_expected.to contain_nova_config('upgrade_levels/cells').with_value('1.0.0')
         is_expected.to contain_nova_config('upgrade_levels/cert').with_value('1.0.0')
@@ -175,9 +168,10 @@ describe 'nova' do
         is_expected.to contain_nova_config('oslo_messaging_notifications/transport_url').with_value('rabbit://rabbit_user:password@localhost:5673')
         is_expected.to contain_nova_config('oslo_messaging_notifications/driver').with_value('ceilometer.compute.nova_notifier')
         is_expected.to contain_nova_config('oslo_messaging_notifications/topics').with_value('openstack')
-        is_expected.to contain_nova_config('DEFAULT/notify_api_faults').with_value(true)
+        is_expected.to contain_nova_config('notifications/notification_format').with_value('unversioned')
+        is_expected.to contain_nova_config('notifications/notify_on_api_faults').with_value(true)
         is_expected.to contain_nova_config('DEFAULT/report_interval').with_value('60')
-        is_expected.to contain_nova_config('DEFAULT/use_ipv6').with_value('true')
+        is_expected.to contain_nova_config('os_vif_linux_bridge/use_ipv6').with_value('true')
         is_expected.to contain_nova_config('cinder/os_region_name').with_value('MyRegion')
       end
 
@@ -201,7 +195,7 @@ describe 'nova' do
       end
 
       it 'configures database' do
-        is_expected.to contain_nova_config('DEFAULT/notify_on_state_change').with_ensure('absent')
+        is_expected.to contain_nova_config('notifications/notify_on_state_change').with_ensure('absent')
       end
     end
 
@@ -211,44 +205,18 @@ describe 'nova' do
       end
 
       it 'configures database' do
-        is_expected.to contain_nova_config('DEFAULT/notify_on_state_change').with_value('vm_state')
+        is_expected.to contain_nova_config('notifications/notify_on_state_change').with_value('vm_state')
       end
     end
 
-    context 'with rabbit_hosts parameter' do
+    context 'with deprecated notify_api_faults parameter' do
       let :params do
-        { :rabbit_hosts => ['rabbit:5673', 'rabbit2:5674'] }
+        { :notify_on_api_faults => :undef,
+          :notify_api_faults    => 'true' }
       end
 
-      it 'configures rabbit' do
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_hosts').with_value('rabbit:5673,rabbit2:5674')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value(true)
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_compression').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>')
-      end
-    end
-
-    context 'with rabbit_hosts parameter (one server)' do
-      let :params do
-        { :rabbit_hosts => ['rabbit:5673'] }
-      end
-
-      it 'configures rabbit' do
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_hosts').with_value('rabbit:5673')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_reconnect_delay').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/amqp_durable_queues').with_value('<SERVICE DEFAULT>')
+      it 'configures notify_on_api_faults using the deprecated parameter' do
+        is_expected.to contain_nova_config('notifications/notify_on_api_faults').with_value('true')
       end
     end
 
@@ -272,10 +240,9 @@ describe 'nova' do
       end
     end
 
-    context 'with rabbit_ha_queues set to false and with rabbit_hosts' do
+    context 'with rabbit_ha_queues set to false' do
       let :params do
-        { :rabbit_ha_queues => 'false',
-          :rabbit_hosts => ['rabbit:5673'] }
+        { :rabbit_ha_queues => false }
       end
 
       it 'configures rabbit' do
@@ -285,73 +252,48 @@ describe 'nova' do
 
     context 'with amqp_durable_queues parameter' do
       let :params do
-        { :rabbit_hosts => ['rabbit:5673'],
-          :amqp_durable_queues => true }
+        { :amqp_durable_queues => true }
       end
 
       it 'configures rabbit' do
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_host').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_port').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_hosts').with_value('rabbit:5673')
         is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_ha_queues').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('oslo_messaging_rabbit/amqp_durable_queues').with_value(true)
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_oslo__messaging__rabbit('nova_config').with(
+          :rabbit_use_ssl => '<SERVICE DEFAULT>',
+        )
       end
     end
 
     context 'with rabbit ssl enabled with kombu' do
       let :params do
-        { :rabbit_hosts       => ['rabbit:5673'],
-          :rabbit_use_ssl     => true,
+        { :rabbit_use_ssl     => true,
           :kombu_ssl_ca_certs => '/etc/ca.cert',
           :kombu_ssl_certfile => '/etc/certfile',
           :kombu_ssl_keyfile  => '/etc/key',
           :kombu_ssl_version  => 'TLSv1', }
       end
 
-      it 'configures rabbit' do
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value(true)
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('/etc/ca.cert')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('/etc/certfile')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('/etc/key')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('TLSv1')
-      end
+      it { is_expected.to contain_oslo__messaging__rabbit('nova_config').with(
+        :rabbit_use_ssl     => true,
+        :kombu_ssl_ca_certs => '/etc/ca.cert',
+        :kombu_ssl_certfile => '/etc/certfile',
+        :kombu_ssl_keyfile  => '/etc/key',
+        :kombu_ssl_version  => 'TLSv1'
+      )}
     end
 
     context 'with rabbit ssl enabled without kombu' do
       let :params do
-        { :rabbit_hosts       => ['rabbit:5673'],
-          :rabbit_use_ssl     => true, }
+        { :rabbit_use_ssl => true, }
       end
 
-      it 'configures rabbit' do
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/rabbit_use_ssl').with_value(true)
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_ca_certs').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_certfile').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_keyfile').with_value('<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('oslo_messaging_rabbit/kombu_ssl_version').with_value('<SERVICE DEFAULT>')
-      end
+      it { is_expected.to contain_oslo__messaging__rabbit('nova_config').with(
+        :rabbit_use_ssl => true,
+      )}
     end
 
-    context 'with rabbitmq rpc_backend with old parameter' do
-      let :params do
-        { :rpc_backend => 'nova.openstack.common.rpc.impl_kombu' }
-      end
-
-      it { is_expected.to contain_nova_config('DEFAULT/rpc_backend').with_value('rabbit') }
-    end
-
-    context 'with amqp rpc_backend default parameters' do
-      let :params do
-        { :rpc_backend => 'amqp' }
-      end
-
+    context 'with amqp default parameters' do
       it 'configures amqp' do
-        is_expected.to contain_nova_config('DEFAULT/rpc_backend').with_value('amqp')
         is_expected.to contain_nova_config('oslo_messaging_amqp/server_request_prefix').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('oslo_messaging_amqp/broadcast_prefix').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('oslo_messaging_amqp/group_request_prefix').with_value('<SERVICE DEFAULT>')
@@ -371,10 +313,9 @@ describe 'nova' do
       end
     end
 
-    context 'with amqp rpc_backend overriden parameters' do
+    context 'with amqp overridden parameters' do
       let :params do
-        { :rpc_backend        => 'amqp',
-          :amqp_idle_timeout  => '60',
+        { :amqp_idle_timeout  => '60',
           :amqp_trace         => true,
           :amqp_ssl_ca_file   => '/etc/ca.cert',
           :amqp_ssl_cert_file => '/etc/certfile',
@@ -385,7 +326,6 @@ describe 'nova' do
       end
 
       it 'configures amqp overide' do
-        is_expected.to contain_nova_config('DEFAULT/rpc_backend').with_value('amqp')
         is_expected.to contain_nova_config('oslo_messaging_amqp/idle_timeout').with_value('60')
         is_expected.to contain_nova_config('oslo_messaging_amqp/trace').with_value('true')
         is_expected.to contain_nova_config('oslo_messaging_amqp/ssl_ca_file').with_value('/etc/ca.cert')
