@@ -40,13 +40,14 @@ describe 'nova::migration::libvirt' do
   shared_examples_for 'nova migration with libvirt' do
 
     context 'with default params' do
-      it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tls').with(:line => "listen_tls = 0") }
-      it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tcp').with(:line => "listen_tcp = 1") }
-      it { is_expected.not_to contain_file_line('/etc/libvirt/libvirtd.conf auth_tls')}
-      it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf auth_tcp').with(:line => "auth_tcp = \"none\"") }
+      it { is_expected.to contain_libvirtd_config('listen_tls').with_value('0') }
+      it { is_expected.to contain_libvirtd_config('listen_tcp').with_value('1') }
+      it { is_expected.not_to contain_libvirtd_config('auth_tls') }
+      it { is_expected.to contain_libvirtd_config('auth_tcp').with_value("\"none\"") }
       it { is_expected.to contain_nova_config('libvirt/live_migration_tunnelled').with_value('<SERVICE DEFAULT>') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_completion_timeout').with_value('<SERVICE DEFAULT>') }
-      it { is_expected.to contain_nova_config('libvirt/live_migration_progress_timeout').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+tcp://%s/system') }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_inbound_addr').with_value('<SERVICE DEFAULT>')}
     end
 
     context 'with override_uuid enabled' do
@@ -69,27 +70,40 @@ describe 'nova::migration::libvirt' do
     context 'with tls enabled' do
       let :params do
         {
-          :use_tls => true,
+          :transport => 'tls',
         }
       end
-      it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tls').with(:line => "listen_tls = 1") }
-      it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tcp').with(:line => "listen_tcp = 0") }
-      it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf auth_tls').with(:line => "auth_tls = \"none\"") }
-      it { is_expected.not_to contain_file_line('/etc/libvirt/libvirtd.conf auth_tcp')}
+      it { is_expected.to contain_libvirtd_config('listen_tls').with_value('1') }
+      it { is_expected.to contain_libvirtd_config('listen_tcp').with_value('0') }
+      it { is_expected.to contain_libvirtd_config('auth_tls').with_value("\"none\"") }
+      it { is_expected.not_to contain_libvirtd_config('auth_tcp') }
       it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+tls://%s/system')}
     end
 
+    context 'with tls enabled and inbound addr set' do
+      let :params do
+        {
+          :transport                   => 'tls',
+          :live_migration_inbound_addr => 'host1.example.com',
+        }
+      end
+      it { is_expected.to contain_libvirtd_config('listen_tls').with_value('1') }
+      it { is_expected.to contain_libvirtd_config('listen_tcp').with_value('0') }
+      it { is_expected.to contain_libvirtd_config('auth_tls').with_value("\"none\"") }
+      it { is_expected.not_to contain_libvirtd_config('auth_tcp') }
+      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+tls://%s/system')}
+      it { is_expected.to contain_nova_config('libvirt/live_migration_inbound_addr').with_value('host1.example.com')}
+    end
+
     context 'with migration flags set' do
       let :params do
         {
           :live_migration_tunnelled          => true,
           :live_migration_completion_timeout => '1500',
-          :live_migration_progress_timeout   => '1500',
         }
       end
       it { is_expected.to contain_nova_config('libvirt/live_migration_tunnelled').with(:value => true) }
       it { is_expected.to contain_nova_config('libvirt/live_migration_completion_timeout').with_value('1500') }
-      it { is_expected.to contain_nova_config('libvirt/live_migration_progress_timeout').with_value('1500') }
     end
 
     context 'with auth set to sasl' do
@@ -98,19 +112,19 @@ describe 'nova::migration::libvirt' do
           :auth => 'sasl',
         }
       end
-      it { is_expected.not_to contain_file_line('/etc/libvirt/libvirtd.conf auth_tls')}
-      it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf auth_tcp').with(:line => "auth_tcp = \"sasl\"") }
+      it { is_expected.not_to contain_libvirtd_config('auth_tls') }
+      it { is_expected.to contain_libvirtd_config('auth_tcp').with_value("\"sasl\"") }
     end
 
     context 'with auth set to sasl and tls enabled' do
       let :params do
         {
           :auth    => 'sasl',
-          :use_tls => true
+          :transport => 'tls'
         }
       end
-      it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf auth_tls').with(:line => "auth_tls = \"sasl\"") }
-      it { is_expected.not_to contain_file_line('/etc/libvirt/libvirtd.conf auth_tcp')}
+      it { is_expected.to contain_libvirtd_config('auth_tls').with_value("\"sasl\"") }
+      it { is_expected.not_to contain_libvirtd_config('auth_tcp') }
     end
 
     context 'with auth set to an invalid setting' do
@@ -129,18 +143,76 @@ describe 'nova::migration::libvirt' do
           :configure_libvirt => false
         }
       end
-      it { is_expected.not_to contain_file_line('/etc/libvirt/libvirtd.conf listen_tls') }
+      it { is_expected.not_to contain_libvirtd_config('listen_tls') }
+      it { is_expected.not_to contain_libvirtd_config('listen_tcp') }
     end
 
     context 'when not configuring nova and tls enabled' do
       let :params do
         {
           :configure_nova => false,
-          :use_tls        => true,
+          :transport      => 'tls',
         }
       end
       it { is_expected.not_to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+tls://%s/system') }
     end
+
+    context 'with listen_address set' do
+      let :params do
+        {
+          :listen_address => "127.0.0.1"
+        }
+      end
+      it { is_expected.to contain_libvirtd_config('listen_addr').with_value("\"127.0.0.1\"") }
+    end
+
+    context 'with ssh transport' do
+      let :params do
+        {
+          :transport => 'ssh',
+        }
+      end
+      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://%s/system')}
+      it { is_expected.to contain_libvirtd_config('listen_tls').with_value('0') }
+      it { is_expected.to contain_libvirtd_config('listen_tcp').with_value('0') }
+    end
+
+    context 'with ssh transport with user' do
+      let :params do
+        {
+          :transport => 'ssh',
+          :client_user => 'foobar'
+        }
+      end
+      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://foobar@%s/system')}
+      it { is_expected.to contain_libvirtd_config('listen_tls').with_value('0') }
+      it { is_expected.to contain_libvirtd_config('listen_tcp').with_value('0') }
+    end
+
+    context 'with ssh transport with port' do
+      let :params do
+        {
+          :transport => 'ssh',
+          :client_port => 1234
+        }
+      end
+      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://%s:1234/system')}
+      it { is_expected.to contain_libvirtd_config('listen_tls').with_value('0') }
+      it { is_expected.to contain_libvirtd_config('listen_tcp').with_value('0') }
+    end
+
+    context 'with ssh transport with extraparams' do
+      let :params do
+        {
+          :transport => 'ssh',
+          :client_extraparams => {'foo' => '%', 'bar' => 'baz'}
+        }
+      end
+      it { is_expected.to contain_nova_config('libvirt/live_migration_uri').with_value('qemu+ssh://%s/system?foo=%%25&bar=baz')}
+      it { is_expected.to contain_libvirtd_config('listen_tls').with_value('0') }
+      it { is_expected.to contain_libvirtd_config('listen_tcp').with_value('0') }
+    end
+
   end
 
   # TODO (degorenko): switch to on_supported_os function when we got Xenial
@@ -154,7 +226,7 @@ describe 'nova::migration::libvirt' do
     end
 
     it_configures 'nova migration with libvirt'
-    it { is_expected.to contain_file_line('/etc/default/libvirt-bin libvirtd opts').with(:line => 'libvirtd_opts="-l"') }
+    it { is_expected.to contain_file_line('/etc/default/libvirtd libvirtd opts').with(:line => 'libvirtd_opts="-l"') }
   end
 
   context 'on Debian platforms release' do
@@ -167,7 +239,7 @@ describe 'nova::migration::libvirt' do
     end
 
     it_configures 'nova migration with libvirt'
-    it { is_expected.to contain_file_line('/etc/default/libvirt-bin libvirtd opts').with(:line => 'libvirtd_opts="-d -l"') }
+    it { is_expected.to contain_file_line('/etc/default/libvirtd libvirtd opts').with(:line => 'libvirtd_opts="-l"') }
   end
 
   context 'on RedHat platforms' do
