@@ -20,7 +20,8 @@ describe 'nova::scheduler' do
       :ensure    => 'running'
     )}
 
-    it { is_expected.to contain_nova_config('DEFAULT/scheduler_driver').with_value('filter_scheduler') }
+    it { is_expected.to contain_nova_config('scheduler/driver').with_value('filter_scheduler') }
+    it { is_expected.to contain_nova_config('scheduler/discover_hosts_in_cells_interval').with_value('<SERVICE DEFAULT>') }
 
     context 'with manage_service as false' do
       let :params do
@@ -46,7 +47,15 @@ describe 'nova::scheduler' do
         { :scheduler_driver => 'custom driver' }
       end
 
-      it { is_expected.to contain_nova_config('DEFAULT/scheduler_driver').with_value('custom driver') }
+      it { is_expected.to contain_nova_config('scheduler/driver').with_value('custom driver') }
+    end
+
+    context 'with discover_hosts_in_cells_interval' do
+      let :params do
+        { :discover_hosts_in_cells_interval => 15 }
+      end
+
+      it { is_expected.to contain_nova_config('scheduler/discover_hosts_in_cells_interval').with_value(15) }
     end
 
     context 'with default database parameters' do
@@ -69,9 +78,11 @@ describe 'nova::scheduler' do
         "
       end
 
-      it { is_expected.to contain_nova_config('database/connection').with_value('mysql://user:pass@db/db').with_secret(true) }
-      it { is_expected.to contain_nova_config('database/slave_connection').with_value('mysql://user:pass@slave/db').with_secret(true) }
-      it { is_expected.to contain_nova_config('database/idle_timeout').with_value('30') }
+      it { is_expected.to contain_oslo__db('nova_config').with(
+        :connection       => 'mysql://user:pass@db/db',
+        :slave_connection => 'mysql://user:pass@slave/db',
+        :idle_timeout     => '30',
+      )}
     end
 
   end
